@@ -1,12 +1,12 @@
 use strict; use warnings;
 package Lingy::HashMap;
 
+use base 'Lingy::Class';
+
 use Lingy::Common;
 
 use Hash::Ordered;
 
-*err = \&Lingy::Common::err;
-
 sub new {
     my ($class, $list) = @_;
     tie my %hash, 'Hash::Ordered';
