@@ -6,18 +6,24 @@ use base 'Lingy::ScalarClass';
 
 use overload cmp => \&comp_pair;
 
-# TODO define lingy.string/join
-sub join {
-    string(
-        CORE::join ${Lingy::RT::str($_[0])},
-            map ${Lingy::RT::str($_)}, @{$_[1]}
+sub append {
+    my ($self, $str) = @_;
+    STRING->new("$self$str");
+}
+
+sub endsWith {
+    my ($str, $substr) = map "$_", @_;
+    my ($l1, $l2) = map length("$_"), @_;
+    BOOLEAN->new(
+        $l1 >= $l2 and
+        substr($str, $l1 - $l2) eq $substr
     );
 }
 
 sub replaceAll {
     my ($str, $pat, $rep) = @_;
     $str =~ s/\Q$pat\E/$rep/g;
-    string($str);
+    STRING->new($str);
 }
 
 sub substring {
@@ -30,15 +36,19 @@ sub substring {
     err "End index out of range '%d' for string length '%d'",
         $offset2, $length
         if $offset2 < $offset1 or $offset2 > $length;
-    string(substr("$string", $offset1, $offset2 - $offset1))
+    STRING->new(substr("$string", $offset1, $offset2 - $offset1))
 }
 
 sub toLowerCase {
-    string(lc $_[0]);
+    STRING->new(lc $_[0]);
+}
+
+sub toString {
+    $_[0];
 }
 
 sub toUpperCase {
-    string(uc $_[0]);
+    STRING->new(uc $_[0]);
 }
 
 sub _to_seq {
